@@ -17,7 +17,10 @@ func setUpThemeListBox(currentTheme string) *gtk.ListBox {
 	listBox, _ := gtk.ListBoxNew()
 	var rowToSelect *gtk.ListBoxRow
 
-	for _, name := range getThemeNames() {
+	themeNames, themePaths := getThemeNames()
+	gtkThemePaths = themePaths
+
+	for _, name := range themeNames {
 		row, _ := gtk.ListBoxRowNew()
 
 		eventBox, _ := gtk.EventBoxNew()
@@ -670,5 +673,16 @@ func setUpProgramSettingsForm() *gtk.Frame {
 	})
 	g.Attach(cb4, 0, 4, 1, 1)
 
+	cb5, _ := gtk.CheckButtonNewWithLabel("~/.config/gtk-4.0/*")
+	cb5.SetActive(preferences.ExportGtk4Symlinks)
+	cb5.Connect("toggled", func() {
+		preferences.ExportGtk4Symlinks = cb5.GetActive()
+	})
+	g.Attach(cb5, 0, 5, 1, 1)
+
+	btn, _ := gtk.ButtonNewWithLabel(voc["clear"])
+	btn.Connect("clicked", clearGtk4Symlinks)
+	g.Attach(btn, 1, 5, 1, 1)
+
 	return frame
 }
